package # hide from PAUSE
        Win32::Console;
use strict;
use warnings;

sub new {}

1
